Package_name : Jetski
=====================

Jetski is a Python library for dealing with Jetski Rental System.

Installation
------------

Use the package manager `pip <https://pip.pypa.io/en/stable/>`__ to
install Jetski.

.. code:: bash

   pip install Jetski

Usage
-----

.. code:: python

   from Jetski import JetskiRental

   shop = JetskiRental()

Contributing
------------

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

Author
------

Tarid Suwansri

License
-------

`MIT <https://choosealicense.com/licenses/mit/>`__
